//
//  PhotoBox.swift
//  NYTPhotoViewer
//
//  Created by Chris Dzombak on 2/2/17.
//  Copyright © 2017 NYTimes. All rights reserved.
//

import UIKit
import NYTPhotoViewer

/// A box allowing NYTPhotoViewer to consume Swift value types from our codebase.
final class NYTPhotoBox: NSObject, NYTPhoto {

    let value: PhotoItem

    init(_ photoItem: PhotoItem) {
        value = photoItem
    }

    // MARK: NYTPhoto

    var image: UIImage?
    var imageData: Data?
    var placeholderImage: UIImage?

    var isPhoto: Bool {
        return value.itemType == .image
    }

    var isView: Bool {
        return value.itemType == .view
    }

    var attributedCaptionTitle: NSAttributedString?

    var attributedCaptionSummary: NSAttributedString? {
        let attributes = [NSAttributedString.Key.foregroundColor:UIColor.white,
                          NSAttributedString.Key.font: UIFont.preferredFont(forTextStyle: .body)]
        return NSAttributedString(string: value.summary, attributes: attributes)
    }

    var attributedCaptionCredit: NSAttributedString? {
        let attributes = [NSAttributedString.Key.foregroundColor:UIColor.gray,
                          NSAttributedString.Key.font: UIFont.preferredFont(forTextStyle: .footnote)]
        return NSAttributedString(string: value.credit, attributes: attributes)
    }
}

// MARK: NSObject Equality

extension NYTPhotoBox {
    @objc
    override func isEqual(_ object: Any?) -> Bool {
        guard let otherPhoto = object as? NYTPhotoBox else { return false }
        return value.identifier == otherPhoto.value.identifier
    }
}
